ImageSource class
图片资源封装类
Constructors
- ImageSource.asset(String assetPath, {ImageFormat? format})
- Asset图片
- ImageSource.auto(dynamic data)
-
自动识别图片资源
factory
- ImageSource.base64(String base64String, {ImageFormat? format})
- Base64图片
- ImageSource.file(String filePath, {ImageFormat? format})
- 本地文件图片
- ImageSource.memory(Uint8List bytes, {ImageFormat? format})
- 内存图片
- ImageSource.network(String url, {ImageFormat? format})
- 网络图片
Properties
- data → dynamic
-
final
- format → ImageFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ImageSourceType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited