EasyImage class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- EasyImage
Constructors
- EasyImage(dynamic image, {Key? key, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap, bool autoDetect = true})
-
构造函数(自动识别模式)
const
- EasyImage.source({Key? key, required ImageSource source, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap})
-
构造函数(手动指定图片源)
const
Properties
- autoDetect → bool
-
是否自动识别图片类型(默认:true)
final
- errorWidget → Widget?
-
错误图
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → dynamic
-
图片资源(支持自动识别)
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onTap → VoidCallback?
-
点击事件
final
- placeholder → Widget?
-
占位图
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → ImageStyle
-
样式配置
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asset(
String assetPath, {Key? key, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap}) → EasyImage - 快捷构造:Asset图片
-
base64(
String base64String, {Key? key, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap}) → EasyImage - 快捷构造:Base64图片
-
circle(
String image, {Key? key, double size = 40, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap}) → EasyImage - 快捷构造:圆形图片
-
network(
String url, {Key? key, ImageStyle style = const ImageStyle(), Widget? placeholder, Widget? errorWidget, VoidCallback? onTap}) → EasyImage - 快捷构造:网络图片